@@ -6,7 +6,7 @@
 # raise a `RecursionError`.
 # In order to avoid this, import only the API that you directly need like:
 #
-#   from .api.jobs_api import JobsApi
+#   from .api.configuration_api import ConfigurationApi
 #
 # or import this package, but before doing it, use:
 #
@@ -14,7 +14,9 @@
 #   sys.setrecursionlimit(n)
 
 # Import APIs into API package:
+from satnogsnetworkapiclient.api.configuration_api import ConfigurationApi
 from satnogsnetworkapiclient.api.jobs_api import JobsApi
 from satnogsnetworkapiclient.api.observations_api import ObservationsApi
+from satnogsnetworkapiclient.api.station_api import StationApi
 from satnogsnetworkapiclient.api.stations_api import StationsApi
 from satnogsnetworkapiclient.api.transmitters_api import TransmittersApi
