@@ -15,10 +15,8 @@ from satnogsnetworkapiclient.model.new_observation import NewObservation
 from satnogsnetworkapiclient.model.observation import Observation
 from satnogsnetworkapiclient.model.paginated_observation_list import PaginatedObservationList
 from satnogsnetworkapiclient.model.paginated_station_list import PaginatedStationList
-from satnogsnetworkapiclient.model.paginated_transmitter_list import PaginatedTransmitterList
 from satnogsnetworkapiclient.model.patched_observation import PatchedObservation
 from satnogsnetworkapiclient.model.station import Station
 from satnogsnetworkapiclient.model.station_configuration import StationConfiguration
-from satnogsnetworkapiclient.model.transmitter import Transmitter
 from satnogsnetworkapiclient.model.transmitter_type_enum import TransmitterTypeEnum
 from satnogsnetworkapiclient.model.update_observation import UpdateObservation
